class Sc68 < Formula
  desc "Play music originally designed for Atari ST and Amiga computers"
  homepage "https://sc68.atari.org/project.html"
  url "https://downloads.sourceforge.net/project/sc68/sc68/2.2.1/sc68-2.2.1.tar.gz"
  sha256 "d7371f0f406dc925debf50f64df1f0700e1d29a8502bb170883fc41cc733265f"
  license "GPL-2.0-or-later"

  livecheck do
    url :stable
    regex(%r{url=.*?/sc68[._-]v?(\d+(?:\.\d+)+)\.t}i)
  end

  head do
    url "https://svn.code.sf.net/p/sc68/code/"

    depends_on "autoconf" => :build
    depends_on "automake" => :build
    depends_on "libtool" => :build
    depends_on "pkg-config" => :build
  end

  uses_from_macos "zlib"

  on_linux do
    depends_on "readline"
  end

  def install
    if build.head?
      system "tools/svn-bootstrap.sh"
    else
      inreplace "configure", "-flat_namespace -undefined suppress", "-undefined dynamic_lookup"
      # Workaround for newer Clang
      odie "Try to remove workaround for Xcode 16 Clang!" if version > "2.2.1"
      ENV.append_to_cflags "-Wno-incompatible-function-pointer-types" if DevelopmentTools.clang_build_version >= 1500
    end

    system "./configure", "--mandir=#{man}",
                          "--infodir=#{info}",
                          *std_configure_args
    system "make", "install"
  end

  test do
    # SC68 ships with a sample module; test attempts to print its metadata
    system bin/"info68", pkgshare/"Sample/About-Intro.sc68", "-C", ": ", "-N", "-L"
  end
end
